@@ -136,8 +136,11 @@
 #' `alpha` is equal to rscale^2 in the BayesFactor package of Morey.
 #' This uses QUADMATH for numerical integration of g.
 #' \item  "ZS-null", a Laplace approximation to the 'JZS' prior
-#' for integration of g.  alpha = 1 only.
-#' \item "ZS-full" (to be deprecated),
+#' for integration of g.  alpha = 1 only. We recommend
+#' using 'JZS' for accuracy and compatibility
+#' with the BayesFactor package, although it is
+#' slower.
+#' \item "ZS-full" (to be deprecated)
 #' \item "hyper-g", a mixture of g-priors where the prior on
 #' g/(1+g) is a Beta(1, alpha/2) as in Liang et al (2008).  This
 #' uses the Cephes library for evaluation of the marginal
@@ -294,7 +297,7 @@
 #' Computational Graphics and Statistics.  20:80-101 \cr
 #' \url{http://dx.doi.org/10.1198/jcgs.2010.09049}
 #'
-#' Clyde, M. and Ghosh. (2012) Finite population estimators in stochastic search variable selection.
+#' Clyde, M. and Ghosh. J. (2012) Finite population estimators in stochastic search variable selection.
 #' Biometrika, 99 (4), 981-988. \url{http://dx.doi.org/10.1093/biomet/ass040}
 #'
 #' Clyde, M. and George, E. I. (2004) Model Uncertainty. Statist. Sci., 19,
@@ -307,7 +310,7 @@
 #' Hoeting, J. A., Madigan, D., Raftery, A. E. and Volinsky, C. T. (1999)
 #' Bayesian model averaging: a tutorial (with discussion). Statist. Sci., 14,
 #' 382-401. \cr
-#' \url{http://www.stat.washington.edu/www/research/online/hoeting1999.pdf}
+#' \url{http://dx.doi.org/10.1214/ss/1009212519}
 #'
 #' Liang, F., Paulo, R., Molina, G., Clyde, M. and Berger, J.O. (2008) Mixtures
 #' of g-priors for Bayesian Variable Selection. Journal of the American
@@ -485,7 +488,7 @@ if (prior == "ZS-full") .Deprecated("prior='JZS'",
   msg="The Zellner-Siow prior will be deprecated in the next version of the
   package. Recommended alternative is the Jeffreys-Zellner-Siow prior 'JZS'")
 
-if (prior == "ZS-null") warning("We recommend using the implementation using the Jeffreys-Zellner-Siow prior (prior='JZS') which uses numerical integration rahter than the Laplace approximation")
+# if (prior == "ZS-null") warning("We recommend using the implementation using the Jeffreys-Zellner-Siow prior (prior='JZS') which uses numerical integration rahter than the Laplace approximation")
 
   method.num = switch(prior,
       "g-prior"=0,
